==> odin_1.8.5.orig.tar.gz: odin-1.8.5/odinreco/dti.h <==
/***************************************************************************
                          dti.h  -  description
                             -------------------
    begin                : Thu Oct 29 2009
    copyright            : (C) 2001 by Thies Jochimsen
    email                : jochimse@cns.mpg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef RECODTI_H
#define RECODTI_H

#include "step.h"

class RecoDTI : public RecoStep {

  // implementing virtual functions of RecoStep
  STD_string label() const {return "dti";}
  STD_string description() const {return "DTI preprocessing";}
  bool process(RecoData& rd, RecoController& controller);
  RecoCoord input_coord() const {return RecoCoord::coord_with_mode(RecoIndex::collected,line3d,line,readout);}
  void modify_coord(RecoCoord& coord) const {}
  RecoStep* allocate() const {return new RecoDTI;}
  void init() {}

};


#endif

==> odin_1.8.8.orig.tar.gz: odin-1.8.8/odinreco/dti.h <==
/***************************************************************************
                          dti.h  -  description
                             -------------------
    begin                : Thu Oct 29 2009
    copyright            : (C) 2000-2014 by Thies Jochimsen
    email                : thies@jochimsen.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef RECODTI_H
#define RECODTI_H

#include "step.h"

class RecoDTI : public RecoStep {

  // implementing virtual functions of RecoStep
  STD_string label() const {return "dti";}
  STD_string description() const {return "DTI preprocessing";}
  bool process(RecoData& rd, RecoController& controller);
  RecoCoord input_coord() const {return RecoCoord::coord_with_mode(RecoIndex::collected,line3d,line,readout);}
  void modify_coord(RecoCoord& coord) const {}
  RecoStep* allocate() const {return new RecoDTI;}
  void init() {}

};


#endif
